@@ -2,10 +2,13 @@ import math
 
 class Vector2d:
     """
-    A mathematical vector.
+    A mathematical vector in 2 dimensions.
 
     ...
 
+    v1.3
+    by EnderRayquaza
+    
     Attributes
     ----------
     x : float
@@ -14,9 +17,14 @@ class Vector2d:
         Its composant y.
     st : float
         Its standard.
-
+    dir : tuple
+        Its direction. It's a vector that its standars is equal to 1.
+        
     Methodes
     --------
+    calculate_param()
+        Calculates its standard and its direction.
+    
     __add__(v)
         Operator +
         Adds the vector v and this vector.
@@ -27,7 +35,11 @@ class Vector2d:
 
     __mul__(k)
         Operator *
-        Multiplies the number k to this vector.
+        Multiplies the number k and this vector.
+
+    __truediv__(k)
+        Operator /
+        Divides the number k to this vector.
 
     __iadd__(v)
         Operator +=
@@ -41,6 +53,10 @@ class Vector2d:
         Operator *=
         Multiplies the number k to this vector.
 
+    __itruediv__(k)
+        Operator /=
+        Divides the number k to this vector.
+
     __pow__(v)
         Operator **
         Returns the scalar product of this vector and v.
@@ -68,6 +84,20 @@ class Vector2d:
         self.x = x
         self.y = y
         self.st = math.sqrt(self.x**2+self.y**2)
+        if(self.st != 0):
+            self.dir = (self.x/self.st, self.y/self.st)
+        else:
+            self.dir = (0, 0)
+
+    def calculate_param(self):
+        """
+        Calculates its standard and its direction.
+        """
+        self.st = math.sqrt(self.x**2+self.y**2)
+        if(self.st != 0):
+            self.dir = (self.x/self.st, self.y/self.st)
+        else:
+            self.dir(0, 0)
 
     def __add__(self, v):
         """
@@ -105,6 +135,18 @@ class Vector2d:
         """
         return Vector2d(self.x*k, self.y*k)
 
+    def __truediv__(self, k):
+        """
+        Operator /
+        Divides the number k to this vector.
+
+        Parameters
+        ----------
+        k : float
+            The number which divided this vector.
+        """
+        return Vector2d(self.x/k, self.y/k)
+
     def __iadd__(self, v):
         """
         Operator +=
@@ -117,7 +159,7 @@ class Vector2d:
         """
         self.x += v.x
         self.y += v.y
-        self.st = math.sqrt(self.x**2+self.y**2)
+        self.calculate_param()
         return self
 
     def __isub__(self, v):
@@ -132,7 +174,7 @@ class Vector2d:
         """
         self.x -= v.x
         self.y -= v.y
-        self.st = math.sqrt(self.x**2+self.y**2)
+        self.calculate_param()
         return self
 
     def __imul__(self, k):
@@ -147,7 +189,22 @@ class Vector2d:
         """
         self.x *= k
         self.y *= k
-        self.st = math.sqrt(self.x**2+self.y**2)
+        self.calculate_param()
+        return self
+
+    def __itruediv__(self, k):
+        """
+        Operator /
+        Divides the number k to this vector.
+
+        Parameters
+        ----------
+        k : float
+            The number which divided this vector.
+        """
+        self.x /= k
+        self.y /= k
+        self.calculate_param()
         return self
 
     def __pow__(self, v):
